GermlineCluster contains output from inferAlleleClusters function.
It includes the allele cluster table, the germline set hierarchical clustering,
and the threshold parameters.
# S4 method for GermlineCluster,missing
plot(x, y = NULL, cex = 1, seed = 9999)GermlineCluster object
not in use. missing.
Controls the size of the allele label. Default is 1.
Set a seed number for drawing the dendrogram. Default 9999.
plot(x = GermlineCluster, y = missing): Plot the dendrogram for the allele clusters.
germlineSetthe original germline set provided
alleleClusterSetthe renamed germline set with the allele clusters
alleleClusterTablethe allele cluster table
hclustAlleleClusterthe hierarchical clustering object of the germline set.
thresholdthe threshold used for the family and the allele clusters.
\link{inferAlleleClusters}