A data.table of the allele similarity cluster table based on the
HVGERM and hv_functionality germlie reference set. This is not the latest
version of the allele similarity cluster table. For the latest version please refer either to the
zenodo doi or you can use the recentAlleleClusters
allele_cluster_tableAn object of class data.table (inherits from data.frame) with 286 rows and 5 columns.
Peres, et al (2022) doi:10.1101/2022.12.26.521922