Cluster the distance matrix from ighvDistance to create the allele clusters based on two thresholds:
75% similarity which represents the family clustering and 95% similarity between alleles which represents the allele clusters
ighvClust(
germline_distance,
family_threshold = 75,
allele_cluster_threshold = 95,
cluster_method = "complete"
)A names list that includes the data.frame of the alleles clusters, the thresholds parameters and the
hierarchical clustering of the germline set.
A germline set distance matrix created by ighvDistance.
The similarity threshold for the family level. Default is 75.
The similarity threshold for the allele cluster level. Default is 95.
The hierarchical clustering method to use. Default is "complete".